@@ -919,6 +919,7 @@ class DateTimeField(DateField):
         return dt
 
     def to_db_value(self, value: Optional[Union[datetime.datetime, datetime.date]]) -> Dict[str, List[bytes]]:
+        dt_str = None
         if value:
             utc = pytz.utc
             dt_str = cast(datetime.datetime, value).astimezone(utc).strftime(self.LDAP_DATETIME_FORMAT)
@@ -1089,6 +1090,23 @@ class CharListField(CharField):
         return super().formfield(**defaults)
 
 
+class CaseInsensitiveSHA1Field(CharField):
+    """
+    This is a readonly field that stores its value as a lowercased SHA1 hash.
+    Use this when you want to store a secret value that you will only ever
+    compare to a similar hashed value.
+    """
+
+    @staticmethod
+    def hash_value(value: Optional[str]) -> Optional[str]:
+        if value:
+            return hashlib.sha1(value.lower().encode('utf-8')).hexdigest()
+        return None
+
+    def to_db_value(self, value: str) -> Dict[str, List[bytes]]:
+        return super().to_db_value(self.hash_value(value))
+
+
 class PasswordField(CharField):
 
     def hash_password(self, password: str) -> bytes:
